@@ -24,7 +24,7 @@ class IssueForm(forms.Form):
             commands = ''
             if self.subsystem is not None:
                 commands += ' Subsystem %s' % self.subsystem
-            commands = ' Customer email ' + self.cleaned_data['email']
+            commands += ' Customer email ' + self.cleaned_data['email']
             connection.executeCommand(issue_id, commands)
             return True
         except YouTrackException:
